# 📚 Documentation

**Complete documentation for the Hyperliquid Manual Trading Bot**

## 📋 Documentation Index

### **🚀 Getting Started**
- **[Setup Guide](setup.md)** - Quick 5-minute installation guide
- **[Commands Reference](commands.md)** - Complete command guide with examples

### **🔧 Technical Documentation**
- **[Project Structure](project-structure.md)** - Codebase organization and architecture
- **[Testing Guide](../tests/README.md)** - Test suite documentation and usage
- **[Deployment Guide](deployment.md)** - Production server deployment

### **📱 Quick Links**

| What You Need | Documentation | Time Required |
|---------------|---------------|---------------|
| **Install & Run** | [Setup Guide](setup.md) | 5 minutes |
| **Learn Commands** | [Commands Reference](commands.md) | 10 minutes |
| **Test Everything** | [Testing Guide](../tests/README.md) | 5 minutes |
| **Understand Code** | [Project Structure](project-structure.md) | 15 minutes |
| **Deploy to Server** | [Deployment Guide](deployment.md) | 20 minutes |

## 🎯 Most Important First

1. **Start Here**: [Setup Guide](setup.md) - Get the bot running
2. **Test Setup**: [Testing Guide](../tests/README.md) - Verify everything works
3. **Learn Commands**: [Commands Reference](commands.md) - Use all features
4. **Deploy**: [Deployment Guide](deployment.md) - Run on server

## 📱 Bot Features Quick Reference

### **💰 Account Management**
```bash
/balance     # Account balance
/positions   # Open positions
/orders      # All open orders
/orders BTC  # BTC orders only
/stats       # Trading statistics
```

### **🔧 Order Management**
```bash
/orders BTC  # View BTC orders
/coo BTC     # Cancel all BTC orders
/exit BTC    # Close BTC position
```

### **🚀 Enhanced Trading**
```bash
/long BTC 100        # Long Bitcoin with $100 (Market)
/long BTC 100 45000  # Long Bitcoin with $100 at $45k (Limit)
/long BTC 100 sl:44000 # Long with automatic stop loss
/short ETH 50        # Short Ethereum with $50 (Market)
/short ETH 50 3500   # Short Ethereum with $50 at $3.5k (Limit)
/short ETH 50 sl:3600 # Short with automatic stop loss
/exit BTC            # Close Bitcoin position
```

### **🛡️ Risk Management**
```bash
/sl BTC 44000        # Stop loss for Bitcoin
/tp BTC 50000        # Take profit for Bitcoin
```

### **📊 Market Data**
```bash
/price       # Quick price check
/market      # Detailed market data
/trades      # Recent trade history
```

## 🆘 Need Help?

- **Quick Start**: See [Setup Guide](setup.md)
- **All Commands**: See [Commands Reference](commands.md)
- **Code Questions**: See [Project Structure](project-structure.md)
- **Server Setup**: See [Deployment Guide](deployment.md)

**Happy trading! 📱💰** 